@@ -7,8 +7,9 @@ from .provider import ContentProvider
 from .reddit import RedditPushshiftProvider
 from .twitter import TwitterTwitterProvider
 from .youtube import YouTubeYouTubeProvider
-from .onlinenews import OnlineNewsWaybackMachineProvider
+from .onlinenews import OnlineNewsWaybackMachineProvider, OnlineNewsMediaCloudProvider
 
+MEDIA_CLOUD_API_KEY = os.getenv('MEDIA_CLOUD_API_KEY', None)
 YOUTUBE_API_KEY = os.getenv('YOUTUBE_API_KEY', None)
 TWITTER_API_BEARER_TOKEN = os.getenv('TWITTER_API_BEARER_TOKEN', None)
 
@@ -25,11 +26,11 @@ PLATFORM_SOURCE_PUSHSHIFT = 'pushshift'
 PLATFORM_SOURCE_TWITTER = 'twitter'
 PLATFORM_SOURCE_YOUTUBE = 'youtube'
 PLATFORM_SOURCE_WAYBACK_MACHINE = 'waybackmachine'
+PLATFORM_SOURCE_MEDIA_CLOUD = 'mediacloud'
 
 NAME_SEPARATOR = "-"
 
 
-
 def provider_name(platform: str, source: str) -> str:
     return platform + NAME_SEPARATOR + source
 
@@ -42,11 +43,13 @@ def available_provider_names() -> List[str]:
         platforms.append(provider_name(PLATFORM_YOUTUBE, PLATFORM_SOURCE_YOUTUBE))
     platforms.append(provider_name(PLATFORM_REDDIT, PLATFORM_SOURCE_PUSHSHIFT))
     platforms.append(provider_name(PLATFORM_ONLINE_NEWS, PLATFORM_SOURCE_WAYBACK_MACHINE))
+    if MEDIA_CLOUD_API_KEY:
+        platforms.append(provider_name(PLATFORM_ONLINE_NEWS, PLATFORM_SOURCE_MEDIA_CLOUD))
     return platforms
 
 
-def provider_by_name(provider_name: str) -> ContentProvider:
-    parts = provider_name.split(NAME_SEPARATOR)
+def provider_by_name(name: str) -> ContentProvider:
+    parts = name.split(NAME_SEPARATOR)
     return provider_for(parts[0], parts[1])
 
 
@@ -68,6 +71,8 @@ def provider_for(platform: str, source: str) -> ContentProvider:
             platform_provider = YouTubeYouTubeProvider(YOUTUBE_API_KEY)
         elif (platform == PLATFORM_ONLINE_NEWS) and (source == PLATFORM_SOURCE_WAYBACK_MACHINE):
             platform_provider = OnlineNewsWaybackMachineProvider()
+        elif (platform == PLATFORM_ONLINE_NEWS) and (source == PLATFORM_SOURCE_MEDIA_CLOUD):
+            platform_provider = OnlineNewsMediaCloudProvider(MEDIA_CLOUD_API_KEY)
         else:
             raise UnknownProviderException(platform, source)
         return platform_provider
